@@ -5,17 +5,18 @@
 # 
 # This is free software, licensed under:
 # 
-#   The GNU General Public License, Version 3, June 2007
+#   The GNU General Public License, Version 2, June 1991
 # 
 use 5.010;
 use strict;
 use warnings;
 
 package Games::Pandemic::Card::Epidemic;
-our $VERSION = '0.8.0';
+our $VERSION = '1.000000';
 
 # ABSTRACT: epidemic card for pandemic
 
+use File::Spec::Functions qw{ catfile };
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
@@ -25,7 +26,7 @@ extends 'Games::Pandemic::Card';
 
 # -- default builders
 
-sub _build_icon  { '' }
+sub _build_icon  { catfile($SHAREDIR, 'cards', 'epidemic-16.png' ) }
 sub _build_label { T('epidemic') }
 
 
@@ -44,13 +45,22 @@ Games::Pandemic::Card::Epidemic - epidemic card for pandemic
 
 =head1 VERSION
 
-version 0.8.0
+version 1.000000
 
 =head1 DESCRIPTION
 
-This package implements a simple epidemic card, not meant to be
-displayed at all. It is here only to mark an epidemic event, drawn among
-other cards.
+This package implements a simple epidemic card. An epidemic event will:
+
+=over 4
+
+=item * Increase the infection rate
+
+=item * Infect a new city with 3 cubes
+
+=item * Intensify the propagation by shuffling the past infections and
+putting them back upon the infection deck
+
+=back 
 
 =head1 AUTHOR
 
@@ -62,7 +72,7 @@ This software is Copyright (c) 2009 by Jerome Quelin.
 
 This is free software, licensed under:
 
-  The GNU General Public License, Version 3, June 2007
+  The GNU General Public License, Version 2, June 1991
 
 =cut 
 
